@@ -1,6 +1,7 @@
 from pathlib import Path
 import ujson as json
 from .utils import fixed_two_decimal_digits, Random
+from .config_parser import TimeParser
 
 
 config_template = Path(__file__).parent / 'config.json'
@@ -20,7 +21,9 @@ if not config_file_path.is_file() or \
 cache = None
 
 
-class Config():
+class Config:
+
+    sub_parser_time = TimeParser()
 
     @staticmethod
     def read_config():
@@ -34,7 +37,7 @@ class Config():
     @staticmethod
     def modify_config_in_runtime(key: str = None, value=None, callback=None):
         """
-          for test only
+        for test only
         """
         global cache
         if callback:
@@ -49,15 +52,14 @@ class Config():
 
     @classmethod
     def new_chinchin_length(cls):
-        min = cls.get_config('new_chinchin_length_random_min')
-        max = cls.get_config('new_chinchin_length_random_max')
+        min = cls.get_config("new_chinchin_length_random_min")
+        max = cls.get_config("new_chinchin_length_random_max")
         return cls.random_value(min, max)
 
     @staticmethod
     def random_value(min: float, max: float):
         return fixed_two_decimal_digits(
-            min + (max - min) * Random.random(),
-            to_number=True
+            min + (max - min) * Random.random(), to_number=True
         )
 
     @staticmethod
@@ -71,33 +73,34 @@ class Config():
 
     @classmethod
     def get_lock_me_punish_value(cls):
-        min = cls.get_config('lock_me_negative_min')
-        max = cls.get_config('lock_me_negative_max')
+        min = cls.get_config("lock_me_negative_min")
+        max = cls.get_config("lock_me_negative_max")
         return cls.random_value(min, max)
 
     @classmethod
     def get_lock_plus_value(cls):
-        min = cls.get_config('lock_plus_min')
-        max = cls.get_config('lock_plus_max')
+        min = cls.get_config("lock_plus_min")
+        max = cls.get_config("lock_plus_max")
         return cls.random_value(min, max)
 
     @classmethod
     def get_glue_plus_value(cls):
-        min = cls.get_config('glue_plus_min')
-        max = cls.get_config('glue_plus_max')
+        min = cls.get_config("glue_plus_min")
+        max = cls.get_config("glue_plus_max")
         return cls.random_value(min, max)
 
     @classmethod
     def is_pk_win(cls, user_length: float, target_length: float):
-        range = cls.get_config('pk_unstable_range_v2')
-        edge = cls.get_config('pk_unstable_range_v2_edge')
+        range = cls.get_config("pk_unstable_range_v2")
+        edge = cls.get_config("pk_unstable_range_v2_edge")
         min_edge = edge[0]
         max_edge = edge[1]
         offset = user_length * range
         min_can_pk_length = user_length - offset
         max_can_pk_length = user_length + offset
         is_in_range = (min_can_pk_length <= target_length) and (
-            target_length <= max_can_pk_length)
+            target_length <= max_can_pk_length
+        )
         if not is_in_range:
             # 绝对赢
             if user_length > target_length:
@@ -125,37 +128,40 @@ class Config():
 
     @classmethod
     def get_pk_plus_value(cls):
-        min = cls.get_config('pk_plus_min')
-        max = cls.get_config('pk_plus_max')
+        min = cls.get_config("pk_plus_min")
+        max = cls.get_config("pk_plus_max")
         return cls.random_value(min, max)
 
     @classmethod
     def get_pk_punish_value(cls):
-        min = cls.get_config('pk_negative_min')
-        max = cls.get_config('pk_negative_max')
+        min = cls.get_config("pk_negative_min")
+        max = cls.get_config("pk_negative_max")
         return cls.random_value(min, max)
 
     @classmethod
     def get_glue_punish_value(cls):
-        min = cls.get_config('glue_negative_min')
-        max = cls.get_config('glue_negative_max')
+        min = cls.get_config("glue_negative_min")
+        max = cls.get_config("glue_negative_max")
         return cls.random_value(min, max)
 
     @classmethod
     def get_lock_punish_with_strong_person_value(cls):
-        min = cls.get_config('lock_me_negative_with_strong_person_min')
-        max = cls.get_config('lock_me_negative_with_strong_person_max')
+        min = cls.get_config("lock_me_negative_with_strong_person_min")
+        max = cls.get_config("lock_me_negative_with_strong_person_max")
         return cls.random_value(min, max)
 
     @classmethod
     def get_glue_self_punish_value(cls):
-        min = cls.get_config('glue_self_negative_min')
-        max = cls.get_config('glue_self_negative_max')
+        min = cls.get_config("glue_self_negative_min")
+        max = cls.get_config("glue_self_negative_max")
         return cls.random_value(min, max)
 
     @classmethod
     def deprecated_tips(cls):
-        if cls.get_config('pk_unstable_range'):
-            print('[Chinchin::Config::Deprecated]: pk_unstable_range is deprecated in v2.4.3, please use pk_unstable_range_v2 instead')
-            print('[Chinchin::Config::Deprecated]: you can remove pk_unstable_range to disable this warning')
-        
+        if cls.get_config("pk_unstable_range"):
+            print(
+                "[Chinchin::Config::Deprecated]: pk_unstable_range is deprecated in v2.4.3, please use pk_unstable_range_v2 instead"
+            )
+            print(
+                "[Chinchin::Config::Deprecated]: you can remove pk_unstable_range to disable this warning"
+            )
